@@ -1,6 +1,14 @@
 #' @export
 universals::pdims
 
+#' @inherit universals::pdims
+#' @export
+pdims.mcmc <- function(x, ...) pdims(as_term(x))
+
+#' @inherit universals::pdims
+#' @export
+pdims.mcmc.list <- function(x, ...) pdims(x[[1]])
+
 #' @inherit universals::pdims
 #' @export
 #'
