@@ -3,10 +3,9 @@
 #' Relists an nlist object that has been unlisted to a named numeric vector.
 #' Ensures absent terms are included and preserves integer class.
 #'
-#' @param flesh An atomic vector
-#' @param skeleton An nlist object.
-#' @return An atomic numeric vector of the values in x.
-#' @seealso [as.nlist.numeric()] and [unlist_nlist()]
+#' @inheritParams params
+#' @return A numeric vector of the values in x.
+#' @seealso [as_nlist.numeric()] and [unlist_nlist()]
 #' @export
 #' @examples
 #' relist_nlist(c(`a[2]` = 5), nlist(a = 1:3))
@@ -36,7 +35,7 @@ relist_nlist <- function(flesh, skeleton) {
   }
   is.na(skeleton[!names(skeleton) %in% names(flesh)]) <- TRUE
   skeleton[names(flesh)] <- unname(flesh)
-  skeleton <- as.nlist(skeleton)
+  skeleton <- as_nlist(skeleton)
   skeleton[names(skeleton) %in% integer] <-
     lapply(skeleton[names(skeleton) %in% integer], as.integer)
   skeleton
